@@ -22,17 +22,10 @@ apparent <- function(data, ...) {
   class(splits) <- c("rsplit", "apparent_split")
   split_objs <- tibble::tibble(splits = list(splits), id = "Apparent")
 
-  new_rset(splits = split_objs$splits,
-           ids = split_objs$id,
-           attrib = NULL,
-           subclass = c("apparent", "rset"))
+  new_rset(
+    splits = split_objs$splits,
+    ids = split_objs$id,
+    attrib = NULL,
+    subclass = c("apparent", "rset")
+  )
 }
-
-#' @export
-print.apparent <- function(x, ...) {
-  cat("#", pretty(x), "\n")
-  class(x) <- class(x)[!(class(x) %in% c("apparent", "rset"))]
-  print(x, ...)
-}
-
-
