@@ -1,26 +1,22 @@
 #' V-Fold Cross-Validation
 #'
-#' V-fold cross-validation randomly splits the data into V groups of roughly
-#'  equal size (called "folds"). A resample of the analysis data consisted of
-#'  V-1 of the folds while the assessment set contains the final fold. In basic
-#'  V-fold cross-validation (i.e. no repeats), the number of resamples is equal
-#'  to V.
-#' @details
-#' The `strata` argument causes the random sampling to be conducted *within
-#'  the stratification variable*. This can help ensure that the number of data
-#'  points in the analysis data is equivalent to the proportions in the original
-#'  data set. (Strata below 10% of the total are pooled together by default.)
-#' When more than one repeat is requested, the basic V-fold cross-validation
-#'  is conducted each time. For example, if three repeats are used with `v =
-#'  10`, there are a total of 30 splits which as three groups of 10 that are
-#'  generated separately.
+#' V-fold cross-validation (also known as k-fold cross-validation) randomly
+#'  splits the data into V groups of roughly equal size (called "folds"). A
+#'  resample of the analysis data consists of V-1 of the folds while the
+#'  assessment set contains the final fold. In basic V-fold cross-validation
+#'  (i.e. no repeats), the number of resamples is equal to V.
+#' @details With more than one repeat, the basic V-fold cross-validation is
+#'  conducted each time. For example, if three repeats are used with `v = 10`,
+#'  there are a total of 30 splits: three groups of 10 that are generated
+#'  separately.
+#' @template strata_details
 #' @inheritParams make_strata
 #' @param data A data frame.
 #' @param v The number of partitions of the data set.
 #' @param repeats The number of times to repeat the V-fold partitioning.
-#' @param strata A variable that is used to conduct stratified sampling to
-#'  create the folds. This could be a single character value or a variable name
-#'  that corresponds to a variable that exists in the data frame.
+#' @param strata A variable in `data` (single character or name) used to conduct
+#'  stratified sampling. When not `NULL`, each resample is created within the
+#'  stratification variable. Numeric `strata` are binned into quartiles.
 #' @param ... Not currently used.
 #' @export
 #' @return A tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and
@@ -39,50 +35,58 @@
 #'
 #' set.seed(13)
 #' folds1 <- vfold_cv(wa_churn, v = 5)
-#' map_dbl(folds1$splits,
-#'         function(x) {
-#'           dat <- as.data.frame(x)$churn
-#'           mean(dat == "Yes")
-#'         })
+#' map_dbl(
+#'   folds1$splits,
+#'   function(x) {
+#'     dat <- as.data.frame(x)$churn
+#'     mean(dat == "Yes")
+#'   }
+#' )
 #'
 #' set.seed(13)
 #' folds2 <- vfold_cv(wa_churn, strata = churn, v = 5)
-#' map_dbl(folds2$splits,
-#'         function(x) {
-#'           dat <- as.data.frame(x)$churn
-#'           mean(dat == "Yes")
-#'         })
+#' map_dbl(
+#'   folds2$splits,
+#'   function(x) {
+#'     dat <- as.data.frame(x)$churn
+#'     mean(dat == "Yes")
+#'   }
+#' )
 #'
 #' set.seed(13)
 #' folds3 <- vfold_cv(wa_churn, strata = tenure, breaks = 6, v = 5)
-#' map_dbl(folds3$splits,
-#'         function(x) {
-#'           dat <- as.data.frame(x)$churn
-#'           mean(dat == "Yes")
-#'         })
+#' map_dbl(
+#'   folds3$splits,
+#'   function(x) {
+#'     dat <- as.data.frame(x)$churn
+#'     mean(dat == "Yes")
+#'   }
+#' )
 #' @export
 vfold_cv <- function(data, v = 10, repeats = 1,
                      strata = NULL, breaks = 4, pool = 0.1, ...) {
-
-  if(!missing(strata)) {
+  if (!missing(strata)) {
     strata <- tidyselect::vars_select(names(data), !!enquo(strata))
-    if(length(strata) == 0) strata <- NULL
+    if (length(strata) == 0) strata <- NULL
   }
 
   strata_check(strata, data)
 
   if (repeats == 1) {
-    split_objs <- vfold_splits(data = data, v = v,
-                               strata = strata, breaks = breaks, pool = pool)
+    split_objs <- vfold_splits(
+      data = data, v = v,
+      strata = strata, breaks = breaks, pool = pool
+    )
   } else {
     for (i in 1:repeats) {
       tmp <- vfold_splits(data = data, v = v, strata = strata, pool = pool)
       tmp$id2 <- tmp$id
       tmp$id <- names0(repeats, "Repeat")[i]
-      split_objs <- if (i == 1)
+      split_objs <- if (i == 1) {
         tmp
-      else
+      } else {
         rbind(split_objs, tmp)
+      }
     }
   }
 
@@ -95,27 +99,32 @@ vfold_cv <- function(data, v = 10, repeats = 1,
 
   cv_att <- list(v = v, repeats = repeats, strata = !is.null(strata))
 
-  new_rset(splits = split_objs$splits,
-           ids = split_objs[, grepl("^id", names(split_objs))],
-           attrib = cv_att,
-           subclass = c("vfold_cv", "rset"))
+  new_rset(
+    splits = split_objs$splits,
+    ids = split_objs[, grepl("^id", names(split_objs))],
+    attrib = cv_att,
+    subclass = c("vfold_cv", "rset")
+  )
 }
 
 
 vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4, pool = 0.1) {
-  if (!is.numeric(v) || length(v) != 1)
-    stop("`v` must be a single integer.", call. = FALSE)
 
   n <- nrow(data)
+  check_v(v, n, call = rlang::caller_env())
+
   if (is.null(strata)) {
     folds <- sample(rep(1:v, length.out = n))
     idx <- seq_len(n)
     indices <- split_unnamed(idx, folds)
   } else {
-    stratas <- tibble::tibble(idx = 1:n,
-                              strata = make_strata(getElement(data, strata),
-                                                   breaks = breaks,
-                                                   pool = pool))
+    stratas <- tibble::tibble(
+      idx = 1:n,
+      strata = make_strata(getElement(data, strata),
+        breaks = breaks,
+        pool = pool
+      )
+    )
     stratas <- split_unnamed(stratas, stratas$strata)
     stratas <- purrr::map(stratas, add_vfolds, v = v)
     stratas <- dplyr::bind_rows(stratas)
@@ -125,8 +134,10 @@ vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4, pool = 0.1) {
   indices <- lapply(indices, default_complement, n = n)
 
   split_objs <- purrr::map(indices, make_splits, data = data, class = "vfold_split")
-  tibble::tibble(splits = split_objs,
-                 id = names0(length(split_objs), "Fold"))
+  tibble::tibble(
+    splits = split_objs,
+    id = names0(length(split_objs), "Fold")
+  )
 }
 
 add_vfolds <- function(x, v) {
@@ -134,9 +145,12 @@ add_vfolds <- function(x, v) {
   x
 }
 
-#' @export
-print.vfold_cv <- function(x, ...) {
-  cat("# ", pretty(x), "\n")
-  class(x) <- class(x)[!(class(x) %in% c("vfold_cv", "rset"))]
-  print(x, ...)
+check_v <- function(v, max_v, rows = "rows", call = rlang::caller_env()) {
+  if (!is.numeric(v) || length(v) != 1 || v < 0) {
+    rlang::abort("`v` must be a single positive integer", call = call)
+  } else if (v > max_v) {
+    rlang::abort(
+      glue::glue("The number of {rows} is less than `v = {v}`"), call = call
+    )
+  }
 }
